<?php

$post_id = get_the_ID();
$polis_convo_id = get_field('polis_conversation_id');
$polis_site_id = get_field('polis_site_id');
$postcodes = get_field('polis_post_codes');
$confirmation_statement = get_field('polis_confirmation_statement');
$area_name = get_field('polis_area_name');
$follow_up = get_field('polis_follow_up');

$postcode_array = array_map('str_getcsv', explode("\n", $postcodes));
$postcode_json = json_encode($postcode_array); ?>

<div class="custom-block polis-container" data-stage-num="1">

    <div class="step" data-stage="1">
        <form id="custom-polis">
            <div class="personal-inputs">
                <input type="text" name="fname" placeholder="first name" />
                <input type="text" name="lname" placeholder="last name" />
                <input type="email" name="email" placeholder="email address" />
                <input type="text" name="postcode" id="post-code" placeholder="post code" />
            </div>
            
            <?php if($area_name) { ?>
            <div class="confirm-inputs">
                <input type="checkbox" name="confirm_area" id="confirm-area" />
                <label for="confirm-area">I confirm that I live and/or work in <?php echo $area_name; ?>.</label>
            </div>
            <?php } ?>

            <div class="confirm-inputs">
                <input type="checkbox" name="confirm_age" id="confirm-age" />
                <label for="confirm-age">I confirm that I am 18 years of age or over.</label>
            </div>

            <div class="statement"><?php echo $confirmation_statement; ?></div>

        </form>
    </div>

    <div class="step" data-stage="2">
        <?php echo $follow_up; ?>
    </div>

    <div class="step" data-stage="3">
        <?php if($polis_convo_id) { 
            // polis conversation using existing conversation ID ?>
            <div class="polis" data-conversation_id="<?php echo $polis_convo_id; ?>"></div>

        <?php } else if($polis_site_id) {
            // generate a new polis poll using the site id ?>
            <div class="polis" data-page_id="<?php echo $post_id; ?>" data-site_id="<?php echo $polis_site_id; ?>"></div>

        <?php } ?>
    </div>

    <div class="polis-form-nav">
        <button class="btn polis-nav" id="polis-back" type="button">Back</button>
        <button class="btn polis-nav" id="polis-next" type="button">Next</button>
    </div>

</div>

<script async src='https://pol.is/embed.js'></script>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        // Select all elements with the "my-button" class
        const buttons = document.querySelectorAll('.polis-nav');

        const postcodes = <?php echo $postcode_json; ?>;

        console.log(postcodes);

        // Loop through the selected elements and add a click event listener to each
        buttons.forEach(button => {
            button.addEventListener('click', function () {

                const container = document.querySelector('.polis-container');
                const form = container.querySelector('#custom-polis');
                const steps = container.querySelectorAll('.step');
                let currentStage = parseInt(container.getAttribute('data-stage-num'));
                const backButton = container.querySelector('#polis-back');
                const nextButton = container.querySelector('#polis-next');

                if(this.id === 'polis-next') {

                    var next = false;
                    var title = 'Error';
                    var text = 'Something went wrong, please try again.';

                    if(currentStage == 1) {

                        var formData = new FormData(form);
                        const formValues = {};
                        formData.forEach((value, key) => {
                            formValues[key] = value;
                        });

                        if(!formValues.fname || !formValues.lname || !formValues.email || !formValues.postcode) {
                            title = "Missing Fields";
                            text = "Please fill out all fields.";

                        } else if(!formValues.confirm_area || !formValues.confirm_age) {
                            title = "Missing Fields";
                            text = "Please confirm both your age and area.";

                        } else {
                            if(postcodes.length === 0) {
                                next = true;
                            } else {
                                next = postcodes.some(subarray => subarray.includes(formValues.postcode));
                                console.log(next);
                                title = "Invalid Postcode";
                                text = "The postcode provided is not allowed for this survey.";       
                            }
                        }                        

                    } else {
                        next = true;
                    }

                    if(next == true) {

                        if((currentStage + 1) == steps.length) {
                            // hide the next button
                            nextButton.style.visibility = 'hidden';
                        } 

                        if(currentStage < steps.length) {
                            // Increment the data-stage-num attribute
                            currentStage++;
                            container.setAttribute('data-stage-num', currentStage);
                        }
                        
                        // Show the "Back" button
                        backButton.style.visibility = 'visible';

                    } else {
                        triggerFormError(title, text);
                        
                    }

                } else if(this.id === 'polis-back') {

                    if((currentStage - 1) == 1) {
                        // hide the next button
                        backButton.style.visibility = 'hidden';
                    } 

                    if(currentStage > 1) {
                        // Decrement the data-stage-num attribute (if not on the first step)
                        currentStage--;
                        container.setAttribute('data-stage-num', currentStage);
                    }

                    // show the next button
                    nextButton.style.visibility = 'visible';

                }

                // Hide all steps and show the relevant step
                steps.forEach(step => {
                    const stepNumber = parseInt(step.getAttribute('data-stage'));
                    if (stepNumber === currentStage) {
                        step.style.display = 'block';
                    } else {
                        step.style.display = 'none';
                    }
                });

            });
        });
    });

    function triggerFormError(title, text) {
        Swal.fire({
            title: title,
            text: text,
            icon: 'error',
            confirmButtonText: 'Dismiss',
        });
    }
</script>